Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(657)

Unified Diff: chrome/browser/resources/settings/a11y_page/manage_a11y_page.js

Issue 2200463002: Reorganize accessibility settings. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address last feedback from dbeam Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
diff --git a/chrome/browser/resources/settings/a11y_page/a11y_page.js b/chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
similarity index 65%
copy from chrome/browser/resources/settings/a11y_page/a11y_page.js
copy to chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
index 2ee16f1d392c79385a03fd02d6ea2abf7aabdf36..c8c2437d2e69e0e23fd17e152d7799d4548ef7d1 100644
--- a/chrome/browser/resources/settings/a11y_page/a11y_page.js
+++ b/chrome/browser/resources/settings/a11y_page/manage_a11y_page.js
@@ -1,21 +1,14 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
* @fileoverview
* 'settings-a11y-page' is the settings page containing accessibility
* settings.
- *
- * Example:
- *
- * <iron-animated-pages>
- * <settings-a11y-page prefs="{{prefs}}"></settings-a11y-page>
- * ... other pages ...
- * </iron-animated-pages>
*/
Polymer({
- is: 'settings-a11y-page',
+ is: 'settings-manage-a11y-page',
properties: {
/**
@@ -26,7 +19,6 @@ Polymer({
notify: true,
},
-<if expr="chromeos">
autoClickDelayOptions_: {
readOnly: true,
type: Array,
@@ -55,8 +47,32 @@ Polymer({
value: function() {
return loadTimeData.getBoolean('showExperimentalA11yFeatures');
},
- }
-</if>
+ },
+ },
+
+ /** @private */
+ onChromeVoxSettingsTap_: function() {
+ chrome.send('showChromeVoxSettings');
+ },
+
+ /** @private */
+ onDisplayTap_: function() {
+ settings.navigateTo(settings.Route.DISPLAY);
+ },
+
+ /** @private */
+ onAppearanceTap_: function() {
+ settings.navigateTo(settings.Route.APPEARANCE);
+ },
+
+ /** @private */
+ onKeyboardTap_: function() {
+ settings.navigateTo(settings.Route.KEYBOARD);
+ },
+
+ /** @private */
+ onMouseTap_: function() {
+ settings.navigateTo(settings.Route.POINTERS);
},
/** @private */
@@ -1,21 +1,14 @@
/**
* @fileoverview
- * 'settings-a11y-page' is the settings page containing accessibility
+ * 'settings-manage-a11y-page' is the subpage with the accessibility
* settings.

Powered by Google App Engine
This is Rietveld 408576698